#!/usr/bin/env python
# Generated by jaraco.develop (https://bitbucket.org/jaraco/jaraco.develop)
import setuptools

with open('README.txt') as readme:
	long_description = readme.read()
with open('CHANGES.txt') as changes:
	long_description += '\n\n' + changes.read()

setup_params = dict(
	name='motivation',
	use_hg_version=True,
	author="YouGov, Plc.",
	author_email="open-source@yougov.com",
	description="motivation",
	long_description=long_description,
	url="https://bitbucket.org/yougov/motivation",
	packages=setuptools.find_packages(),
	setup_requires=[
		'hgtools',
		'pytest-runner>=2.1',
	],
	entry_points=dict(
		pmxbot_handlers=[
			'motivation = motivation.commands',
		],
	),
	tests_require=[
		'pytest',
		'pmxbot',
	],
)
if __name__ == '__main__':
	setuptools.setup(**setup_params)
